@@ -8,11 +8,12 @@ from __future__ import unicode_literals, print_function, division
 
 import ast
 import collections
+import itertools
 import math
 import pkgutil
 import re
 
-__all__ = ['format_grid', 'parse_grid', 'sheet_keys']
+__all__ = ['format_grid', 'parse_grid', 'sheet_keys', 'get_sheet']
 
 GRID_SQ_LETTERS = 'VWXYZQRSTULMNOPFGHJKABCDE'
 GRID_SIZE = int(math.sqrt(len(GRID_SQ_LETTERS)))
@@ -24,7 +25,8 @@ MAX_GRID_SIZE = MINOR_GRID_SQ_SIZE * len(GRID_SQ_LETTERS)
 
 
 def get_sheet(key):
-    '''Fetch a map from the locker
+    '''Fetch a map from the locker:
+
     >>> print(get_sheet("A:1").title)
     Shetland - Yell, Unst and Fetlar
 
@@ -81,7 +83,7 @@ def _load_maps(series, filename):
             float(area),
             series, number, parent, title,
             ast.literal_eval(polygon)
-            )
+        )
 
     return maps
 
@@ -181,11 +183,9 @@ class FarFarAwayError(GridFormatError):
         self.northing = northing
 
     def __str__(self):
-        return "The spot with coordinates" \
-                + " " \
-                + "({:g}, {:g})".format(self.easting, self.northing) \
-                + " " \
-                + "is too far from the OSGB grid"
+        return "The spot with coordinates " \
+            + "({}, {})".format(self.easting, self.northing) \
+            + " is too far from the OSGB grid"
 
 
 def _is_left_right_or_on(x, y, a, b):
@@ -202,15 +202,22 @@ def _is_left_right_or_on(x, y, a, b):
     return (b[0] - a[0]) * (y - a[1]) - (x - a[0]) * (b[1] - a[1])
 
 
+def _pairwise(iterable):
+    # _pairwise('ABCDEFG') --> AB BC CD DE EF FG
+    a, b = itertools.tee(iterable)
+    next(b, None)
+    return zip(a, b)
+
+
 def _winding_number(x, y, poly):
     '''This is adapted from http://geomalgorithms.com/a03-_inclusion.html'''
     w = 0
-    for i in range(len(poly)-1):
-        if poly[i][1] <= y:
-            if poly[i+1][1] > y and _is_left_right_or_on(x, y, poly[i], poly[i+1]) > 0:
+    for a, b in _pairwise(poly):
+        if a[1] <= y:
+            if b[1] > y and _is_left_right_or_on(x, y, a, b) > 0:
                 w += 1
         else:
-            if poly[i+1][1] <= y and _is_left_right_or_on(x, y, poly[i], poly[i+1]) < 0:
+            if b[1] <= y and _is_left_right_or_on(x, y, a, b) < 0:
                 w -= 1
     return w
 
@@ -343,8 +350,8 @@ def format_grid(easting, northing=None, form='SS EEE NNN'):
         raise FaultyFormError(form)
 
     (space_a, e_spec, space_b, n_spec) = m.group(1, 2, 3, 4)
-    e = int(e/10**(5-len(e_spec)))
-    n = int(n/10**(5-len(n_spec)))
+    e = int(e / 10 ** (5 - len(e_spec)))
+    n = int(n / 10 ** (5 - len(n_spec)))
 
     return sq \
         + space_a + '{0:0{1}d}'.format(e, len(e_spec)) \
@@ -536,7 +543,7 @@ If there's no matching input then a GarbageError error is raised.
 
         en_tuple = _get_eastings_northings(grid_string)
         if en_tuple is not None:
-            return (en_tuple[0]+offsets[0], en_tuple[1]+offsets[1])
+            return (en_tuple[0] + offsets[0], en_tuple[1] + offsets[1])
 
     # just a pair of numbers perhaps?
     try:
@@ -553,7 +560,17 @@ If there's no matching input then a GarbageError error is raised.
 
 
 def _get_easting_northing_from_sheet_reference(possible_map_gr):
-    '''Find a grid reference from a sheet number (with optional local GR)'''
+    '''Find a grid reference from a sheet number (with optional local GR)
+
+    >>> _get_easting_northing_from_sheet_reference('A:195/291849')
+    (429100, 84900)
+
+    >>> _get_easting_northing_from_sheet_reference('A:195/29184')  # doctest: +IGNORE_EXCEPTION_DETAIL
+    Traceback (most recent call last):
+    ...
+    GarbageError: I can't read a grid reference from this -> 29184
+
+    '''
 
     # so lets try to decompose the string version of the input
     ok = re.match(r'^([A-Z]:)?([0-9NEWSOL/]+?)(\.[a-z]+)?(?:[ -/.]([ 0-9]+))?$', possible_map_gr)
@@ -579,7 +596,10 @@ def _get_easting_northing_from_sheet_reference(possible_map_gr):
     northing = s.bbox[0][1]
 
     if numbers is not None:
-        (e, n) = _get_eastings_northings(numbers)
+        try:
+            (e, n) = _get_eastings_northings(numbers)
+        except TypeError:  # in case we get None back
+            raise GarbageError(numbers)
         easting = easting + (e - easting) % MINOR_GRID_SQ_SIZE
         northing = northing + (n - northing) % MINOR_GRID_SQ_SIZE
         if _winding_number(easting, northing, s.polygon) == 0:
@@ -597,6 +617,9 @@ def _get_grid_square_offsets(sq):
     >>> _get_grid_square_offsets('TQ 345 452')
     (500000, 100000)
 
+    >>> _get_grid_square_offsets('') is None
+    True
+
     """
 
     if len(sq) < 2:
@@ -634,7 +657,7 @@ def _get_eastings_northings(s):
         gr = t[0]
         f = len(gr)
         if f in [2, 4, 6, 8, 10]:
-            f = int(f/2)
+            f = int(f / 2)
             e, n = (gr[:f], gr[f:])
         else:
             return None
@@ -642,10 +665,10 @@ def _get_eastings_northings(s):
         return None
 
     figs = min(5, max(len(e), len(n)))
-    return (int(e)*10**(5-figs), int(n)*10**(5-figs))
+    return (int(e) * 10 ** (5 - figs), int(n) * 10 ** (5 - figs))
 
 
-def sheet_keys(easting, northing, series='ABCHJ'):
+def sheet_keys(easting, northing=None, series='ABCHJ'):
     """Return a list of map sheet keys that show the (easting, northing)
     point given.
 
@@ -699,7 +722,25 @@ def sheet_keys(easting, northing, series='ABCHJ'):
     >>> sheet_keys(0, 0)
     []
 
+    You can pass a tuple as argument if you prefer, so that you can
+    call sheet_keys directly with parse_grid
+
+    >>> print(' '.join(sheet_keys(parse_grid("SZ294849"))))
+    A:195 A:196 B:OL29W C:180
+    >>> print(' '.join(sheet_keys(parse_grid("SZ294849"), series='A')))
+    A:195 A:196
+
+    But we don't call parse_grid automatically for you...
+
+    >>> sheet_keys("SZ294849")
+    []
+
     """
+    if northing is None:
+        if type(easting) is tuple:
+            (easting, northing) = easting
+        else:
+            return []
 
     sheets = list()
     for (k, m) in map_locker.items():
@@ -712,8 +753,3 @@ def sheet_keys(easting, northing, series='ABCHJ'):
                     sheets.append(k)
 
     return sorted(sheets)
-
-
-if __name__ == "__main__":
-    import doctest
-    doctest.testmod()
